function [H P SEL PosTUp SE0] = BCER(A,B,Delay,Alpha)

%   BCER       Binary data, Causal inference approach based on the analysis of Events of Relations 
%              test A->B in Delay; H=1, indicates A causes B;
%              If there are more than one delay, H correspond to each delay;
%
%   H = BCER(A,B);       % 10 Delays, from 1 to 10 ;
%   [H P] = BCER(A,B,Delay,Alpha);
%   v 1.0
%
%   Input:      A,      binary data
%               B,      binary data
%               Delay,  Delay times 
%               Alpha,  performs the test at the (100*alpha)% significance level.
%
%   Outputs:    H,      indicates A causes B or not, correspond to each delay
%               P,      p-value of the test
%               SEL,    number of Events of Relation correspond to each delay
%               PosTUp, The upper limit of the confidence intervals 
%               SE0,    number of Rvents of Relation at 0 delay
%
%   Note: Delay must be positive
% 
%   Reference: Yu Yin, et al. (2015)  Causal Inference Based on the Analysis of Events 
%                of Relations for Non-stationary Neural Signals 
%
%   Yu Yin, UESTC, China 2013-2015
%   Email: yu.yin@uestc.edu.cn

if nargin == 2
    Delay = 10;        % 10 Delays, from 1 to 10 ;
    Alpha = 0.005;
end
if nargin == 3
    Alpha = 0.005;
end

L_A = length(A);
L_B = length(B);

L_using = min([L_A L_B]);

E1 = find(A(1:L_using));
E2 = find(B(1:L_using));


SE0 = length(intersect(E1,E2));     % number of events of relation at 0 delay
PosTUp = poissinv(1-Alpha,SE0);     % The upper limit of the confidence intervals 

SEL = zeros(1,Delay);       
H = zeros(1,Delay);
P = zeros(1,Delay);
for i=1:Delay  
    SEL(i) = length(intersect(E1+i,E2));
    H(i) = SEL(i) > PosTUp;     
    P(i) = 1 - poisscdf(SEL(i),SE0);    
end


